@@ -7,22 +7,18 @@ from gi.repository import Gtk
 from gajim.common import app
 from gajim.common import configpaths
 configpaths.init()
-from gajim.common import caps_cache
+from gajim.common.helpers import AdditionalDataDict
 
 from gajim.conversation_textview import ConversationTextview
 from gajim.gui_interface import Interface
 
-caps_cache.capscache = MagicMock()
 app.plugin_manager = MagicMock()
 app.logger = MagicMock()
+app.cert_store = MagicMock()
 app.interface = Interface()
 
 
 XHTML = [
-    '''
-    <body xmlns='http://www.w3.org/1999/xhtml'><p><span style='font-size: xx-large;'>rexxnor: i nimes chum a...</span></p></body>
-    ''',
-
     '''
     <div>
         <span style="color: red; text-decoration:underline">Hello</span>
@@ -31,7 +27,6 @@ XHTML = [
         <br/>\n
         <span style="font-size: 500%; font-family: serif">World</span>\n
     </div>
-    \n
     ''',
 
     '''
@@ -40,19 +35,23 @@ XHTML = [
 
     '''
     <body xmlns='http://www.w3.org/1999/xhtml'>
-        <p xmlns='http://www.w3.org/1999/xhtml'>a:b 
-            <a href='http://google.com/' xmlns='http://www.w3.org/1999/xhtml'>Google</a>
+        <p xmlns='http://www.w3.org/1999/xhtml'>Look here 
+            <a href='http://google.com/'>Google</a>
         </p>
         <br/>
     </body>
     ''',
 
+    '''
+    <hr />
+    ''',
+
     '''
     <body xmlns='http://www.w3.org/1999/xhtml'>
         <p style='font-size:large'>
             <span style='font-style: italic'>O
             <span style='font-size:larger'>M</span>G
-            </span>, I&apos;m <span style='color:green'>green</span>with 
+            </span>, I&apos;m <span style='color:green'>green</span> with 
             <span style='font-weight: bold'>envy</span>!
         </p>
     </body>
@@ -64,18 +63,11 @@ XHTML = [
 
     '''
     <body xmlns='http://www.w3.org/1999/xhtml'>
-        http://test.com/  testing links autolinkifying
-    </body>
-    ''',
-
-    '''
-    <hr />
-    ''',
-
-    '''
-    <body xmlns='http://www.w3.org/1999/xhtml'>
-        <p>As Emerson said in his essay <span style='
-            font-style: italic; background-color:cyan'>Self-Reliance</span>:</p>
+        <p>
+            As Emerson said in his essay 
+            <span style='font-style: italic; background-color:cyan'>
+            Self-Reliance</span>:
+        </p>
         <p style='margin-left: 5px; margin-right: 2%'>
             &quot;A foolish consistency is the hobgoblin of little minds.&quot;
         </p>
@@ -174,7 +166,6 @@ XHTML = [
 
     '''
     <body xmlns='http://www.w3.org/1999/xhtml'>
-        <br/>
         <img src='data:image/png;base64,R0lGODdhMAAwAPAAAAAAAP///ywAAAAAMAAw\
             AAAC8IyPqcvt3wCcDkiLc7C0qwyGHhSWpjQu5yqmCYsapyuvUUlvONmOZtfzgFz\
             ByTB10QgxOR0TqBQejhRNzOfkVJ+5YiUqrXF5Y5lKh/DeuNcP5yLWGsEbtLiOSp\
@@ -204,7 +195,10 @@ class TextviewWindow(Gtk.Window):
 
     def _print_xhtml(self):
         for xhtml in XHTML:
-            self._textview.print_real_text(None, xhtml=xhtml)
+            additional_data = AdditionalDataDict()
+            additional_data.set_value('gajim', 'xhtml', xhtml)
+            self._textview.print_real_text(None, additional_data=additional_data)
+            self._textview.print_real_text('\n')
 
 win = TextviewWindow()
 win.connect("destroy", Gtk.main_quit)
