@@ -34,11 +34,7 @@ class MockConnection(Mock, ConnectionHandlers):
         app.to_be_removed[account] = []
         app.nicks[account] = app.config.get_per('accounts', account, 'name')
         app.block_signed_in_notifications[account] = True
-        app.sleeper_state[account] = 0
         app.last_message_time[account] = {}
-        app.status_before_autoaway[account] = ''
-        app.gajim_optional_features[account] = []
-        app.caps_hash[account] = ''
 
         app.connections[account] = self
 
@@ -102,20 +98,8 @@ class MockInterface(Mock):
         from gajim import plugins
         app.plugin_manager = plugins.PluginManager()
 
-        self.remote_ctrl = None
         self.instances = {}
         self.minimized_controls = {}
-        self.status_sent_to_users = Mock()
-
-        if app.use_x:
-            self.jabber_state_images = {'16': {}, '24': {}, '32': {},
-                'opened': {}, 'closed': {}}
-
-            from gajim import gtkgui_helpers
-            gtkgui_helpers.make_jabber_state_images()
-        else:
-            self.jabber_state_images = {'16': Mock(), '24': Mock(),
-                '32': Mock(), 'opened': Mock(), 'closed': Mock()}
 
 
 class MockLogger(Mock):
