@@ -25,11 +25,10 @@ git+https://github.com/enthought/pywin32-ctypes.git
 python-axolotl
 python-gnupg
 keyring
-cssutils
+css_parser
 qrcode
-precis-i18n
 "
-
+pip3 install precis-i18n
 pip3 install $(echo "$PIP_REQUIREMENTS" | tr ["\\n"] [" "])
 
 }
